|PyPI| |versions| |license| |docs| |CI| |coverage|

===============================
SMufoLib: Where SMuFL meets UFO
===============================

.. _intro:

SMufoLib is a lightweight Python library for working with fonts that follow the
`Standard Music Font Layout <https://w3c.github.io/smufl/latest/>`_ (SMuFL). It builds
on the reference implementation of the `FontParts
<https://fontparts.robotools.dev/en/stable/index.html>`_ API and operates directly on the
`Unified Font Object <https://unifiedfontobject.org>`_ (UFO) format. SMufoLib enhances
these foundations with SMuFL-aware tools for music font design, scripting and metadata
management -- all from the command line, without requiring a GUI font editor.

.. _documentation:

Documentation
=============

SMufoLib's documentation is available at `smufolib.readthedocs.io
<https://smufolib.readthedocs.io/en/latest/index.html>`_.

.. _installation:

Installation
============

SMufoLib requires `Python <http://www.python.org/download/>`__ 3.10 or later. It is
listed in the `Python Package Index <https://pypi.org/project/smufolib>`_ (PyPI) and can
be installed with `pip <https://pip.pypa.io/>`__:

.. code-block:: console

   $ python -m pip install smufolib


.. |PyPI| image:: https://img.shields.io/pypi/v/smufolib
   :alt: PyPI - Version
   :target: https://pypi.org/project/smufolib/

.. |versions| image:: https://img.shields.io/pypi/pyversions/smufolib
   :alt: PyPI - Python Version
   :target: https://www.python.org

.. |license| image:: https://img.shields.io/pypi/l/smufolib
   :alt: PyPI - License
   :target: https://opensource.org/license/mit

.. |docs| image:: https://img.shields.io/readthedocs/smufolib
   :alt: Read the Docs
   :target: https://smufolib.readthedocs.io/en/latest/

.. |CI| image:: https://img.shields.io/github/actions/workflow/status/knutnergaard/smufolib/ci.yml?event=push&label=CI
   :alt: GitHub Actions Workflow Status
   :target: https://github.com/knutnergaard/smufolib/actions

.. |coverage| image:: https://img.shields.io/codecov/c/github/knutnergaard/smufolib?labelColor=grey&color=%23FF69B4
   :alt: Codecov
   :target: https://app.codecov.io/github/knutnergaard/smufolib


